@@ -25,13 +25,14 @@ Generator::Map Generator::s_insert =
     {"polymorphicSpecializations",  &Generator::polymorphicSpecializations},
     {"preincludes",                 &Generator::preIncludes},
     {"print",                       &Generator::print},
-    {"requiredtokens",              &Generator::requiredTokens},
+    {"prompt",                      &Generator::prompt},
+    {"baseclasscode",               &Generator::baseClassCode},
     {"actioncases",                 &Generator::actionCases},
     {"staticdata",                  &Generator::staticData},
-    {"threading",                   &Generator::threading},
     {"tokens",                      &Generator::tokens},
     {"warnTagMismatches",           &Generator::warnTagMismatches},
     {"LTYPE",                       &Generator::ltype},
+    {"LTYPEclear",                  &Generator::ltypeClear},
     {"LTYPEdata",                   &Generator::ltypeData},
     {"LTYPEpop",                    &Generator::ltypePop},
     {"LTYPEpush",                   &Generator::ltypePush},
@@ -45,7 +46,6 @@ vector<Generator::AtBool> Generator::s_atBol =
     AtBool("@insert-stype", &Generator::ifInsertStype),
     AtBool("@printtokens",  &Generator::ifPrintTokens),
     AtBool("@ltype",        &Generator::ifLtype),
-    AtBool("@thread-safe",  &Generator::ifThreadSafe),
     AtBool("@else",         &Generator::atElse),
     AtBool("@end",          &Generator::atEnd),
 };
